"""
Collection of tasks to interact with Stitch APIs.
In order to use Stitch APIs, you'll need to have
a Stitch Unlimited Plan or higher.
For further information, checkout [Stitch pricing](https://www.stitchdata.com/pricing/).
"""

from typing import Dict

from prefect import task

from prefect_stitch.credentials import StitchCredentials
from prefect_stitch.stitch_client import StitchClient


@task
def start_replication_job(credentials: StitchCredentials, source_id: int) -> Dict:
    """
    This task starts a new Stitch replication job using the provided source.

    Args:
        access_token: API access token that will be used to authenticate API calls.
        source_id: integer identifier of the source that will
            be used in the replication job.

    Returns:
        Replication job API JSON response.
    """
    stitch_client = StitchClient(credentials=credentials)
    return stitch_client.start_replication_job(source_id=source_id)



"""Stitch credentials block"""
from prefect.blocks.core import Block
from pydantic import SecretStr


class StitchCredentials(Block):
    """
    Block used to manage authentication with Stitch.
    Args:
        access_token (SecretStr): The Access token to use to connect to Stitch.

    Example:
        Load stored Stitch credentials
        ```python
        from prefect_stitch.credentials import StitchCredentials
        stitch_credentials_block = StitchCredentials.load("BLOCK_NAME")
        ```
    """  # noqa E501

    access_token: SecretStr

    _block_type_name = "Stitch Credentials"

    _logo_url = "https://github.com/PrefectHQ/prefect/blob/main/docs/img/collections/stitch.png?raw=true"  # noqa
